@@ -162,3 +162,87 @@ test_that("splt() works with force_equal on vector", {
   ## Finished testing 'splt_equal(df, c(3, 5), "l_starts", starts_c...'     ####
 
 })
+
+
+test_that("splt() works with group_by()", {
+  xpectr::set_test_seed(42)
+
+  df <- data.frame(
+    "x" = c(1:12),
+    "species" = factor(rep(c("cat", "pig", "human"), 4)),
+    "age" = c(5, 65, 34, 54, 32, 54, 23, 65, 23, 65, 87, 98)
+  )
+
+
+  ## Testing 'xpectr::suppress_mw(df %>% dplyr::group_by(s...'              ####
+  ## Initially generated by xpectr
+  xpectr::set_test_seed(42)
+  # Assigning output
+  output_19148 <- xpectr::suppress_mw(df %>%
+      dplyr::group_by(species) %>%
+      splt(n = 2))
+  # Testing class
+  expect_equal(
+    class(output_19148),
+    "list",
+    fixed = TRUE)
+  # Testing type
+  expect_type(
+    output_19148,
+    type = "list")
+  # Testing values
+  expect_equal(
+    output_19148[["1"]],
+    list(`1` = structure(list(x = c(1L, 4L), species = structure(c(1L,
+      1L), .Label = c("cat", "human", "pig"), class = "factor"), age = c(5,
+      54)), row.names = c(NA, -2L), class = c("tbl_df", "tbl", "data.frame")),
+      `2` = structure(list(x = c(7L, 10L), species = structure(c(1L,
+          1L), .Label = c("cat", "human", "pig"), class = "factor"),
+          age = c(23, 65)), row.names = c(NA, -2L), class = c("tbl_df",
+          "tbl", "data.frame"))))
+  expect_equal(
+    output_19148[["2"]],
+    list(`1` = structure(list(x = c(3L, 6L), species = structure(c(2L,
+      2L), .Label = c("cat", "human", "pig"), class = "factor"), age = c(34,
+      54)), row.names = c(NA, -2L), class = c("tbl_df", "tbl", "data.frame")),
+      `2` = structure(list(x = c(9L, 12L), species = structure(c(2L,
+          2L), .Label = c("cat", "human", "pig"), class = "factor"),
+          age = c(23, 98)), row.names = c(NA, -2L), class = c("tbl_df",
+          "tbl", "data.frame"))))
+  expect_equal(
+    output_19148[["3"]],
+    list(`1` = structure(list(x = c(2L, 5L), species = structure(c(3L,
+      3L), .Label = c("cat", "human", "pig"), class = "factor"), age = c(65,
+      32)), row.names = c(NA, -2L), class = c("tbl_df", "tbl", "data.frame")),
+      `2` = structure(list(x = c(8L, 11L), species = structure(c(3L,
+          3L), .Label = c("cat", "human", "pig"), class = "factor"),
+          age = c(65, 87)), row.names = c(NA, -2L), class = c("tbl_df",
+          "tbl", "data.frame"))))
+  # Testing names
+  expect_equal(
+    names(output_19148),
+    c("1", "2", "3"),
+    fixed = TRUE)
+  # Testing length
+  expect_equal(
+    length(output_19148),
+    3L)
+  # Testing sum of element lengths
+  expect_equal(
+    sum(xpectr::element_lengths(output_19148)),
+    6L)
+  # Testing element classes
+  expect_equal(
+    xpectr::element_classes(output_19148),
+    c("list", "list", "list"),
+    fixed = TRUE)
+  # Testing element types
+  expect_equal(
+    xpectr::element_types(output_19148),
+    c("list", "list", "list"),
+    fixed = TRUE)
+  ## Finished testing 'xpectr::suppress_mw(df %>% dplyr::group_by(s...'     ####
+
+
+
+})
